@@ -2,7 +2,7 @@ import numpy as np
 
 def load_en():
     embeddings_dict = dict()
-    f = open('./data/cc.en.300.vec')
+    f = open('../data/cc.en.300.vec')
     lines = f.readlines()
 
     for line in lines[1:]:
@@ -17,7 +17,7 @@ def load_en():
 
 def load_de():
     embeddings_dict = dict()
-    f = open('./data/cc.de.300.vec')
+    f = open('../data/cc.de.300.vec')
     lines = f.readlines()
 
     for line in lines[1:]:
@@ -28,4 +28,4 @@ def load_de():
 
     f.close()
 
-    return embeddings_dict
\ No newline at end of file
+    return embeddings_dict
